gchecky.model.billing_address_t

Package gchecky :: Module model :: Class billing_address_t |
[hide private]
[frames] | no frames]

# Class billing_address_t

source code

    object --+
             |
     gxml.Node --+
                 |
         address_t --+
                     |
                    billing_address_t

Nested Classes | [hide private]
Inherited from `gxml.Node`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Methods | [hide private]
Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| address_id = `ID:PATH(@address-id):OPT`
| _fields = ``{``'``address1``'``:` String:PATH(address1):REQ`,` `'``address2``'``:` `...`` list of meta-Fields of this class.
Inherited from `address_t`: `address1`, `address2`, `city`, `company_name`, `contact_name`, `country_code`, `email`, `fax`, `phone`, `postal_code`, `region`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### _fields list of meta-Fields of this class. Value:
      {'address1': String:PATH(address1):REQ,
       'address2': String:PATH(address2):OPT,
       'address_id': ID:PATH(@address-id):OPT,
       'city': String:PATH(city):REQ,
       'company_name': String:PATH(company-name):OPT,
       'contact_name': String:PATH(contact-name):OPT,
       'country_code': String:PATH(country-code):REQ,
       'email': Email:PATH(email):OPT,
      ...